@@ -115,7 +115,7 @@ class StructFactory(TypeFactory):
   PROVIDES = 'Struct'
 
   @staticmethod
-  def create(type_dict, *type_parameters):
+  def create(type_dict, *type_parameters, class_cell=None):
     """
       StructFactory.create(*type_parameters) expects:
 
@@ -127,6 +127,7 @@ class StructFactory(TypeFactory):
          (attribute_name2, attribute_sig2 ...),
          ...
          (attribute_nameN, ...))
+        class_cell inherited from StructMetaclass
     """
     name, parameters = type_parameters
     for param in parameters:
@@ -134,6 +135,8 @@ class StructFactory(TypeFactory):
     typemap = dict((attr, TypeSignature.deserialize(param, type_dict))
                    for attr, param in parameters)
     attributes = {'TYPEMAP': typemap}
+    if class_cell:
+      attributes['__classcell__'] = class_cell
     return TypeMetaclass(str(name), (Structural,), attributes)
 
 
@@ -153,7 +156,7 @@ class StructMetaclass(type):
   def __new__(mcs, name, parents, attributes):
     if any(parent.__name__ == 'Struct' for parent in parents):
       type_parameters = StructMetaclass.attributes_to_parameters(attributes)
-      return TypeFactory.new({}, 'Struct', name, type_parameters)
+      return TypeFactory.new({}, 'Struct', name, type_parameters, class_cell=attributes.pop('__classcell__', None))
     else:
       return type.__new__(mcs, name, parents, attributes)
 
